@@ -4,7 +4,7 @@
 // Defines determined during configuration of m4ri.
 #define __M4RI_HAVE_MM_MALLOC		1
 #define __M4RI_HAVE_POSIX_MEMALIGN	1
-#define __M4RI_HAVE_SSE2		1
+#define __M4RI_HAVE_SSE2		0
 #define __M4RI_HAVE_OPENMP		1
 #define __M4RI_CPU_L1_CACHE		32768
 #define __M4RI_CPU_L2_CACHE		1048576
@@ -14,8 +14,8 @@
 #define __M4RI_HAVE_LIBPNG              1
 
 #define __M4RI_CC                       "gcc"
-#define __M4RI_CFLAGS                   " -mmmx -msse -msse2 -msse3 -fopenmp -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/m4ri/src=/usr/src/debug/m4ri -flto=auto"
-#define __M4RI_SIMD_CFLAGS              " -mmmx -msse -msse2 -msse3"
+#define __M4RI_CFLAGS                   " -fopenmp -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/m4ri/src=/usr/src/debug/m4ri -flto=auto"
+#define __M4RI_SIMD_CFLAGS              ""
 #define __M4RI_OPENMP_CFLAGS            "-fopenmp"
 
 // Helper macros.
